==> vmaid-1.8.6.tar.gz: vmaid-1.8.6/dllloader/gdi32.c <==
/*
    dllloader
    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "gdi32.h"
#include "module.h"
#include "windef.h"


/******************************************************************************
*                                                                             *
* GDI                                                                         *
*                                                                             *
******************************************************************************/
typedef HANDLE HGDIOBJ;


static HDC WINAPI CreateCompatibleDC(HDC hdc)
{
	return NULL;
}


static BOOL WINAPI BitBlt(
					HDC hdcDest,INT nXDest,INT nYDest,INT nWidth,INT nHeight,
									HDC hdcSrc,INT nXSrc,INT nYSrc,DWORD dwRop)
{
	return FALSE;
}


static HGDIOBJ WINAPI SelectObject(HDC hdc,HGDIOBJ hgdiobj)
{
	return NULL;
}


static BOOL WINAPI DeleteObject(HGDIOBJ hObject)
{
	return FALSE;
}


static UINT WINAPI GetSystemPaletteEntries(HDC hdc,
				UINT iStartIndex,UINT nEntries,LPVOID/*LPPALETTEENTRY*/ lppe)
{
	return 0;
}


static BOOL WINAPI DeleteDC(HDC hdc)
{
	return FALSE;
}


static INT WINAPI GetObjectA(HGDIOBJ hgdiobj,INT cbBuffer,LPVOID lpvObject)
{
	return 0;
}


/******************************************************************************
*                                                                             *
* Ͽ                                                                        *
*                                                                             *
******************************************************************************/
static VOID WINAPI UnknownSymbol(VOID)
{
	g_message("unknown symbol in gdi32 called\n");
}


static SymbolInfo symbol_infos[]={
	{"CreateCompatibleDC",CreateCompatibleDC},
	{"BitBlt",BitBlt},
	{"SelectObject",SelectObject},
	{"DeleteObject",DeleteObject},
	{"GetSystemPaletteEntries",GetSystemPaletteEntries},
	{"DeleteDC",DeleteDC},
	{"GetObjectA",GetObjectA},
	{NULL,UnknownSymbol}
};


SymbolInfo *gdi32_get_export_symbols(void)
{
	module_register("gdl32.dll",symbol_infos);
	return symbol_infos;
}

==> vmaid-1.8.7.tar.gz: vmaid-1.8.7/dllloader/gdi32.c <==
/*
    dllloader
    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "gdi32.h"
#include "module.h"


/******************************************************************************
*                                                                             *
* GDI                                                                         *
*                                                                             *
******************************************************************************/
typedef HANDLE HGDIOBJ;


static HDC WINAPI CreateCompatibleDC(HDC hdc)
{
	return NULL;
}


static BOOL WINAPI BitBlt(
					HDC hdcDest,INT nXDest,INT nYDest,INT nWidth,INT nHeight,
									HDC hdcSrc,INT nXSrc,INT nYSrc,DWORD dwRop)
{
	return FALSE;
}


static HGDIOBJ WINAPI SelectObject(HDC hdc,HGDIOBJ hgdiobj)
{
	return NULL;
}


static BOOL WINAPI DeleteObject(HGDIOBJ hObject)
{
	return FALSE;
}


static UINT WINAPI GetSystemPaletteEntries(HDC hdc,
				UINT iStartIndex,UINT nEntries,LPVOID/*LPPALETTEENTRY*/ lppe)
{
	return 0;
}


static BOOL WINAPI DeleteDC(HDC hdc)
{
	return FALSE;
}


static INT WINAPI GetObjectA(HGDIOBJ hgdiobj,INT cbBuffer,LPVOID lpvObject)
{
	return 0;
}


/******************************************************************************
*                                                                             *
* o^                                                                        *
*                                                                             *
******************************************************************************/
static VOID WINAPI UnknownSymbol(VOID)
{
	g_message("unknown symbol in gdi32 called\n");
}


static SymbolInfo symbol_infos[]={
	{"CreateCompatibleDC",CreateCompatibleDC},
	{"BitBlt",BitBlt},
	{"SelectObject",SelectObject},
	{"DeleteObject",DeleteObject},
	{"GetSystemPaletteEntries",GetSystemPaletteEntries},
	{"DeleteDC",DeleteDC},
	{"GetObjectA",GetObjectA},
	{NULL,UnknownSymbol}
};


SymbolInfo *gdi32_get_export_symbols(void)
{
	module_register("gdl32.dll",symbol_infos);
	return symbol_infos;
}
